library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;               -- for type conversions

use work.gbt_bank_package.all;
use work.vendor_specific_gbt_bank_package.all;

entity mgt_unused is
  generic (
      NUM_LINKS : natural := 1
    );
  port (
    clk_i   : in std_logic;
    rx_p_i  : in std_logic_vector(NUM_LINKS-1 downto 0);
    rx_n_i  : in std_logic_vector(NUM_LINKS-1 downto 0);
    tx_p_o  : out std_logic_vector(NUM_LINKS-1 downto 0);
    tx_n_o  : out std_logic_vector(NUM_LINKS-1 downto 0)
  ) ;
end mgt_unused;

architecture mgt_unused_arc of mgt_unused is
  
  signal MGT_TXRESET_i       : std_logic_vector(1 to NUM_LINKS) := (others => '0');
  signal MGT_RXRESET_i       : std_logic_vector(1 to NUM_LINKS) := (others => '0');
  signal MGT_AUTORSTEn_i     : std_logic_vector(1 to NUM_LINKS) := (others => '0');
  signal MGT_AUTORSTONEVEN_i : std_logic_vector(1 to NUM_LINKS) := (others => '0');
  signal MGT_USRWORD_i       : word_mxnbit_A(1 to NUM_LINKS) := (others => (others => '0'));
  signal MGT_DEVSPEC_i       : mgtDeviceSpecific_i_R;
  signal MGT_DEVSPEC_o       : mgtDeviceSpecific_o_R;
   
begin
  
  mgt_1 : entity work.mgt
    generic map (
      NUM_LINKS => NUM_LINKS
    )
    port map (
      MGT_REFCLK_i        => clk_i,
      MGT_RXUSRCLK_o      => open,
      MGT_TXUSRCLK_o      => open,
      MGT_TXRESET_i       => MGT_TXRESET_i,
      MGT_RXRESET_i       => MGT_RXRESET_i,
      MGT_TXREADY_o       => open,
      MGT_RXREADY_o       => open,
      RX_HEADERLOCKED_o   => open,
      RX_HEADERFLAG_o     => open,
      MGT_RSTCNT_o        => open,
      MGT_AUTORSTEn_i     => MGT_AUTORSTEn_i,
      MGT_AUTORSTONEVEN_i => MGT_AUTORSTONEVEN_i,
      MGT_USRWORD_i       => MGT_USRWORD_i,
      MGT_USRWORD_o       => open,
      MGT_DEVSPEC_i       => MGT_DEVSPEC_i,
      MGT_DEVSPEC_o       => MGT_DEVSPEC_o
    );

    numbers : for i in 1 to NUM_LINKS generate      
      tx_p_o(i-1)              <= MGT_DEVSPEC_o.tx_p(i);
      tx_n_o(i-1)              <= MGT_DEVSPEC_o.tx_n(i);
      MGT_DEVSPEC_i.rx_p(i)    <= rx_p_i(i-1) ; -- std_logic_vector(1 to MAX_NUM_GBT_LINK);                                 
      MGT_DEVSPEC_i.rx_n(i)    <= rx_n_i(i-1) ; -- std_logic_vector(1 to MAX_NUM_GBT_LINK);  
    end generate;
    
    MGT_DEVSPEC_i.reset_freeRunningClock     <= (others => '0');  -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.loopBack                   <= (others => (others => '0')); -- gbt_devspec_reg3_A(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.tx_reset                   <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.rx_reset                   <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.conf_diffCtrl              <= (others => (others => '0')); -- gbt_devspec_reg4_A(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.conf_postCursor            <= (others => (others => '0')); -- gbt_devspec_reg5_A(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.conf_preCursor             <= (others => (others => '0')); -- gbt_devspec_reg5_A(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.conf_txPol                 <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.conf_rxPol                 <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.drp_addr                   <= (others => (others => '0')); -- gbt_devspec_reg9_A(1 to MAX_NUM_GBT_LINK);  
    MGT_DEVSPEC_i.drp_clk                    <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);  
    MGT_DEVSPEC_i.drp_en                     <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.drp_di                     <= (others => (others => '0')); -- gbt_devspec_reg16_A(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.drp_we                     <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.prbs_txSel                 <= (others => (others => '0')); -- gbt_devspec_reg3_A(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.prbs_rxSel                 <= (others => (others => '0')); -- gbt_devspec_reg3_A(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.prbs_txForceErr            <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);
    MGT_DEVSPEC_i.prbs_rxCntReset            <= (others => '0'); -- std_logic_vector(1 to MAX_NUM_GBT_LINK);

end  mgt_unused_arc;