library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;               -- for type conversions

entity saturated_counter is
  generic (
      g_counter_len : natural := 8
    );
  port (
    i_clk : in std_logic;
    i_rst : in std_logic;

    i_pulse : in std_logic;

    o_val : out unsigned(g_counter_len-1 downto 0)
  ) ;
end saturated_counter;

architecture saturated_counter_arc of saturated_counter is

  signal    r_value         : unsigned(g_counter_len-1 downto 0);
  constant  r_value_full    : unsigned(g_counter_len-1 downto 0) := (others => '1'); 

begin

  cnt_sp : process (i_clk)
  begin
    if (rising_edge(i_clk)) then
      if i_rst='1' then
        r_value <= (others => '0');

      elsif r_value/=r_value_full and i_pulse='1' then
        r_value  <= r_value+1;

      end if;
    end if;
  end process cnt_sp;

end  saturated_counter_arc;